-- -------------------------------------------------------------------------- --
-- FlightMaster (NPC DATA)                                                  ¶ --
-- -------------------------------------------------------------------------- --

-- -------------------------------------------------------------------------- --
-- Zones:                                                                     --
-- - Kalimdor (1)                                                             --
-- - EasternKingdoms (2)                                                      --
-- - Outland (3)                                                              --
-- - Northrend (4)                                                            --
-- - Pandaria (5)                                                             --
-- -------------------------------------------------------------------------- --

-- -------------------------------------------------------------------------- --
-- Flight Point exceptions:                                                   --
-- LVL -> l = available at level xx                                           --
-- C   -> c = class specific                                                  --
-- +Q  -> a = available after quest                                           --
-- -Q  -> u = unavailable after quest                                         --
-- UW  -> w = underwater                                                      --
-- F   -> f = faction (Aldor or Scryers, Burning Crusade)                     --
-- =   -> s = same node, but different phase                                  --
-- -------------------------------------------------------------------------- --
FlightMaster_exNPC = {
	["Horde"] = {
		["Kalimdor"] = {
			[43549] = "1614654#a=25608", -- NEUTRAL  | Gates of Sothann, Hyjal -- Only available after completion of N [81] Slash and Burn [25608]
			[54392] = "1537668#s=54393", -- NEUTRAL  | Sanctuary of Malorne, Hyjal -- Same Node as NPC 54393, but different phase.
			[54393] = "1537668#s=54392", -- NEUTRAL  | Sanctuary of Malorne, Hyjal -- Same Node as NPC 54392, but different phase.
		},
		["EasternKingdoms"] = {
			[26560] = "1583942#l=65", -- NEUTRAL  | Shattered Sun Staging Area
			[29480] = "1623656#c=DEATHKNIGHT", -- NEUTRAL  | Acherus: The Ebon Hold -- Death Knight only
			[45479] = "1369542#a=27290:u=27438", -- HORDE    | Forsaken Forward Command, Gilneas -- available after completion of H [14] To Forsaken Forward Command [27290]; unavailable after completion of H [16] The Great Escape [27438]
			[47121] = "1563469#a=27564", -- NEUTRAL  | Vermillion Redoubt, Twilight Highlands -- Only available after completion of N [85] In Defense of the Redoubt
			[47174] = "1646435#a=26830", -- HORDE    | Dragonmaw Port, Twilight Highlands -- Only available after completion of H [84] Traitor's Bait [26830]

			[40851] = "1277362#w", -- NEUTRAL  | Silver Tide Hollow, Vashj'ir -- UNDERWATER
			[40852] = "1305415#w", -- NEUTRAL  | Smuggler's Scar, Vashj'ir -- UNDERWATER
			[40871] = "1280338#w", -- HORDE    | Legion's Rest, Vashj'ir -- UNDERWATER
			[40873] = "1215348#w", -- HORDE    | Tenebrous Cavern, Vashj'ir -- UNDERWATER
			[43216] = "1297377#w", -- HORDE    | Sandy Beach, Vashj'ir -- UNDERWATER
			[43225] = "1279335#a=26006", -- HORDE    | Stygian Bounty, Vashj'ir -- Only available after completion of N [81] A Breath of Fresh Air [26006]
			[43293] = "1277335#w:a=26006", -- HORDE    | Stygian Bounty, Vashj'ir -- UNDERWATER -- Only available after completion of N [81] A Breath of Fresh Air [26006]
		},
		["Outland"] = {
			[19581] = "1809228#f=aldor", -- NEUTRAL  | Altar of Sha'tar, Shadowmoon Valley -- Aldor only!
			[21766] = "1778146#f=scryers", -- NEUTRAL  | Sanctum of the Stars, Shadowmoon Valley -- Scryers only!
		},
		["Northrend"] = {
			[28037] = "1175603#a=12523", -- NEUTRAL  | Nesingwary Base Camp, Sholazar Basin -- Only available after completion of N [76] Have a Part, Give a Part
			[30314] = "1377785#a=12897", -- NEUTRAL  | The Shadow Vault, Icecrown -- Only available after completion of N [80] If He Cannot Be Turned
			[31069] = "1522655#a=13141", -- NEUTRAL  | Crusaders' Pinnacle, Icecrown -- Only available after completion of N [79] The Battle For Crusaders' Pinnacle
			[32571] = "1720714#a=12956", -- NEUTRAL  | Dun Niffelem, The Storm Peaks -- Only available after completion of N [80] A Spark of Hope
		},
		["Pandaria"] = {
			[60952] = "1678492#a=29936", -- HORDE    | Grookin Hill, Jade Forest -- Only available after completion of H [85] Instant Messaging [questID 29936]
			[61745] = "1558562#a=30515", -- HORDE    | Eastwind Rest, Kun-Lai Summit -- Only available after completion of H [87] Challenge Accepted [questID 30515]
		},
	},
	["Alliance"] = {
		["Kalimdor"] = {
			[43549] = "1614654#a=25608", -- NEUTRAL  | Gates of Sothann, Hyjal -- Only available after completion of N [81] Slash and Burn [25608]
			[54392] = "1537668#s=54393", -- NEUTRAL  | Sanctuary of Malorne, Hyjal -- Same Node as NPC 54393, but different phase.
			[54393] = "1537668#s=54392", -- NEUTRAL  | Sanctuary of Malorne, Hyjal -- Same Node as NPC 54392, but different phase.
		},
		["EasternKingdoms"] = {
			[26560] = "1583942#l=65", -- NEUTRAL  | Shattered Sun Staging Area
			[29480] = "1623656#c=DEATHKNIGHT", -- NEUTRAL  | Acherus: The Ebon Hold -- Death Knight only
			[46006] = "1471622#u=27206", -- ALLIANCE | Andorhal, Western Plaguelands -- becomes unavailable after completion of A [40] Alas, Andorhal
			[47119] = "1660405#a=28598", -- ALLIANCE | Highbank, Twilight Highlands -- Only available after completion of A [84] Aiming High
			[47121] = "1563469#a=27564", -- NEUTRAL  | Vermillion Redoubt, Twilight Highlands -- Only available after completion of N [85] In Defense of the Redoubt

			[40851] = "1277362#w", -- NEUTRAL  | Silver Tide Hollow, Vashj'ir -- UNDERWATER
			[40852] = "1305415#w", -- NEUTRAL  | Smuggler's Scar, Vashj'ir -- UNDERWATER
			[40866] = "1220334#w", -- ALLIANCE | Darkbreak Cove, Vashj'ir -- UNDERWATER
			[40867] = "1276344#w", -- ALLIANCE | Tranquil Wash, Vashj'ir -- UNDERWATER
			[43287] = "1291391#w", -- ALLIANCE | Sandy Beach, Vashj'ir -- UNDERWATER
			[43289] = "1290324#w:a=26005", -- ALLIANCE | Voldrin's Hold, Vashj'ir -- UNDERWATER -- Only available after completion of N [81] A Breath of Fresh Air
			[43295] = "1290324#a=26005", -- ALLIANCE | Voldrin's Hold, Vashj'ir -- Only available after completion of N [81] A Breath of Fresh Air
		},
		["Outland"] = {
			[19581] = "1809228#f=aldor", -- NEUTRAL  | Altar of Sha'tar, Shadowmoon Valley -- Aldor only!
			[21766] = "1778146#f=scryers", -- NEUTRAL  | Sanctum of the Stars, Shadowmoon Valley -- Scryers only!
		},
		["Northrend"] = {
			[28037] = "1175603#a=12523", -- NEUTRAL  | Nesingwary Base Camp, Sholazar Basin -- Only available after completion of N [76] Have a Part, Give a Part
			[30314] = "1377785#a=12896", -- NEUTRAL  | The Shadow Vault, Icecrown -- Only available after completion of N [80] If He Cannot Be Turned
			[31069] = "1522655#a=13141", -- NEUTRAL  | Crusaders' Pinnacle, Icecrown -- Only available after completion of N [79] The Battle For Crusaders' Pinnacle
			[32571] = "1720714#a=12956", -- NEUTRAL  | Dun Niffelem, The Storm Peaks -- Only available after completion of N [80] A Spark of Hope
		},
		["Pandaria"] = {
			[59049] = "1656278#a=30274", -- ALLIANCE | The Incursion, Krasarang Wilds -- Only available after completion of A [86] The Arcanic Oubliette [30274]
			[61744] = "1513549#a=30514", -- ALLIANCE | Westwind Rest, Kun-Lai Summit -- Only available after completion of A [87] Challenge Accepted [30514]
		},
	}
}

-- -------------------------------------------------------------------------- --
-- Flight Points:                                                             --
-- -------------------------------------------------------------------------- --
FlightMaster_NPC = {
	["Horde"] = {
		["Kalimdor"] = {
			 [2995] = 1449438, -- HORDE    | Thunder Bluff, Mulgore
			 [3310] = 1630562, -- HORDE    | Orgrimmar, Durotar
			 [3615] = 1557470, -- HORDE    | The Crossroads, Northern Barrens
			 [4312] = 1408527, -- HORDE    | Sun Rock Retreat, Stonetalon Mountains
			 [6726] = 1317415, -- HORDE    | Shadowprey Village, Desolace
			 [7824] = 1607196, -- HORDE    | Gadgetzan, Tanaris
			 [8610] = 1709633, -- HORDE    | Bilgewater Harbor, Azshara
			[10583] = 1514178, -- NEUTRAL  | Marshal's Stand, Un'Goro Crater
			[11139] = 1640768, -- HORDE    | Everlook, Winterspring
			[11899] = 1567358, -- HORDE    | Brackenwall Village, Dustwallow Marsh
			[11901] = 1407625, -- HORDE    | Zoram'gar Outpost, Ashenvale
			[12616] = 1554582, -- HORDE    | Splintertree Post, Ashenvale
			[12740] = 1538795, -- HORDE    | Moonglade
			[15178] = 1416208, -- HORDE    | Cenarion Hold, Silithus
			[16227] = 1606451, -- NEUTRAL  | Ratchet, Northern Barrens
			[22931] = 1505651, -- NEUTRAL  | Emerald Sanctuary, Felwood
			[34429] = 1471613, -- HORDE    | Hellscream's Watch, Ashenvale
			[34927] = 1541537, -- HORDE    | The Mor'Shan Ramparts, Ashenvale
			[34943] = 1498576, -- HORDE    | Silverwind Refuge, Ashenvale
			[35139] = 1461483, -- HORDE    | Malaka'jin, Stonetalon Mountains
			[35140] = 1452526, -- HORDE    | Krom'gar Fortress, Stonetalon Mountains
			[35141] = 1400578, -- HORDE    | Cliffwalker Post, Stonetalon Mountains
			[35315] = 1359470, -- HORDE    | Furien's Post, Desolace
			[35478] = 1383445, -- NEUTRAL  | Karnum's Glade, Desolace
			[35556] = 1407466, -- NEUTRAL  | Thunk's Abode, Desolace
			[35562] = 1349473, -- NEUTRAL  | Ethel Rethor, Desolace
			[36728] = 1622610, -- HORDE    | Valormok, Azshara
			[37005] = 1706596, -- HORDE    | Southern Rocketway, Azshara
			[39175] = 1496202, -- NEUTRAL  | Mossy Pile, Un'Goro Crater
			[39330] = 1520353, -- HORDE    | Desolation Hold, Southern Barrens
			[39340] = 1516455, -- HORDE    | Hunter's Hill, Southern Barrens
			[39898] = 1443306, -- HORDE    | Camp Mojache, Feralas
			[40358] = 1583300, -- NEUTRAL  | Mudsprocket, Dustwallow Marsh
			[40473] = 1346361, -- HORDE    | Camp Ataya, Feralas
			[40558] = 1590535, -- HORDE    | Nozzlepot's Outpost, Northern Barrens
			[40769] = 1611238, -- HORDE    | Fizzle & Pozzik's Speedbarge, Thousand Needles
			[40809] = 1466393, -- HORDE    | Bloodhoof Village, Mulgore
			[41140] = 1647499, -- HORDE    | Razor Hill, Durotar
			[41142] = 1652456, -- HORDE    | Sen'jin Village, Durotar
			[41214] = 1619131, -- NEUTRAL  | Bootlegger Outpost, Tanaris
			[41215] = 1552098, -- HORDE    | Dawnrise Expedition, Tanaris
			[41246] = 1421563, -- HORDE    | The Sludgewerks, Stonetalon Mountains
			[41605] = 1373298, -- HORDE    | Stonemaul Hold, Feralas
			[41860] = 1523700, -- NEUTRAL  | Grove of Aessina, Hyjal
			[41861] = 1597717, -- NEUTRAL  | Nordrassil, Hyjal
			[43073] = 1485737, -- NEUTRAL  | Whisperwind Grove, Felwood
			[43079] = 1487682, -- NEUTRAL  | Wildheart Point, Felwood
			[43085] = 1517771, -- HORDE    | Irontree Clearing, Felwood
			[43328] = 1740677, -- HORDE    | Northern Rocketway, Azshara
			[43481] = 1561693, -- NEUTRAL  | Shrine of Aviana, Hyjal
			[43549] = 1614654, -- NEUTRAL  | Gates of Sothann, Hyjal -- Only available after completion of N [81] Slash and Burn [25608]
			[44399] = 1489311, -- HORDE    | Westreach Summit, Thousand Needles
			[48273] = 1407048, -- NEUTRAL  | Schnottz's Landing, Uldum
			[48274] = 1418144, -- NEUTRAL  | Oasis of Vir'sar, Uldum
			[48275] = 1494101, -- NEUTRAL  | Ramkahen, Uldum
			[52060] = 1522399, -- HORDE    | Vendetta Point, Southern Barrens
			[54392] = 1537668, -- NEUTRAL  | Sanctuary of Malorne, Hyjal
			[54393] = 1537668, -- NEUTRAL  | Sanctuary of Malorne, Hyjal
		},
		["EasternKingdoms"] = {
			 [1387] = 1421143, -- HORDE    | Grom'gol, Stranglethorn
			 [2226] = 1373591, -- HORDE    | The Sepulcher, Silverpine Forest
			 [2389] = 1456573, -- HORDE    | Tarren Mill, Hillsbrad
			 [2851] = 1547542, -- HORDE    | Hammerfall, Arathi
			 [2858] = 1408072, -- HORDE    | Booty Bay, Stranglethorn
			 [2861] = 1511342, -- HORDE    | New Kargath, Badlands
			 [3305] = 1464346, -- HORDE    | Thorium Point, Searing Gorge
			 [4314] = 1590552, -- HORDE    | Revantusk Village, The Hinterlands
			 [4551] = 1417628, -- HORDE    | Undercity, Tirisfal
			 [6026] = 1540211, -- HORDE    | Stonard, Swamp of Sorrows
			[12636] = 1612653, -- HORDE    | Light's Hope Chapel, Eastern Plaguelands
			[13177] = 1502313, -- HORDE    | Flame Crest, Burning Steppes
			[16189] = 1578754, -- HORDE    | Tranquillien, Ghostlands
			[16192] = 1592816, -- HORDE    | Silvermoon City
			[24851] = 1612726, -- NEUTRAL  | Zul'Aman, Ghostlands
			[26560] = 1583942, -- NEUTRAL  | Shattered Sun Staging Area
			[28621] = 1577683, -- NEUTRAL  | Northpass Tower, Eastern Plaguelands
			[29480] = 1623656, -- NEUTRAL  | Acherus: The Ebon Hold -- Death Knight only
			[37888] = 1520641, -- NEUTRAL  | Thondroril River, Eastern Plaguelands
			[37915] = 1452634, -- HORDE    | The Bulwark, Tirisfal
			[43052] = 1454154, -- HORDE    | Bambala, Stranglethorn
			[43053] = 1401113, -- HORDE    | Hardwrench Hideaway, Stranglethorn
			[43086] = 1561236, -- NEUTRAL  | Bogpaddle, Swamp of Sorrows
			[43104] = 1481541, -- HORDE    | Galen's Fall, Arathi
			[43114] = 1532145, -- HORDE    | Sunveil Excursion, Blasted Lands
			[43121] = 1523194, -- HORDE    | Dreadmaul Hold, Blasted Lands
			[43124] = 1413653, -- HORDE    | Brill, Tirisfal Glades
			[43220] = 1297377, -- HORDE    | Sandy Beach, Vashj'ir
			[43225] = 1279335, -- HORDE    | Stygian Bounty, Vashj'ir -- Only available after completion of N [81] A Breath of Fresh Air [26006]
			[43573] = 1524573, -- HORDE    | Hiri'watha Research Station, The Hinterlands
			[44036] = 1574794, -- HORDE    | Fairbreeze Village, Eversong Woods
			[44230] = 1592662, -- NEUTRAL  | Eastwall Tower, Eastern Plaguelands
			[44231] = 1579653, -- NEUTRAL  | Light's Shield Tower, Eastern Plaguelands
			[44232] = 1554639, -- NEUTRAL  | Crown Guard Tower, Eastern Plaguelands
			[44233] = 1531677, -- NEUTRAL  | Plaguewood Tower, Eastern Plaguelands
			[44244] = 1578821, -- HORDE    | Falconwing Square, Eversong Woods
			[44407] = 1561346, -- NEUTRAL  | Fuselight, Badlands
			[44408] = 1548334, -- HORDE    | Bloodwatcher Point, Badlands
			[44825] = 1391623, -- HORDE    | Forsaken High Command, Silverpine Forest
			[45479] = 1369542, -- HORDE    | Forsaken Forward Command, Gilneas -- available after completion of H [14] To Forsaken Forward Command [27290]; unavailable after completion of H [16] The Great Escape [27438]
			[46004] = 1481626, -- HORDE    | Andorhal, Western Plaguelands
			[46011] = 1487639, -- NEUTRAL  | The Menders' Stead, Western Plaguelands
			[46552] = 1380570, -- HORDE    | The Forsaken Front, Silverpine Forest
			[47061] = 1649477, -- HORDE    | The Krazzworks, Twilight Highlands
			[47116] = 1594406, -- HORDE    | Crushblow, Twilight Highlands
			[47121] = 1563469, -- NEUTRAL  | Vermillion Redoubt, Twilight Highlands -- Only available after completion of N [85] In Defense of the Redoubt [27564]
			[47133] = 1578453, -- HORDE    | The Gullet, Twilight Highlands
			[47156] = 1610448, -- HORDE    | Bloodgulch, Twilight Highlands
			[47174] = 1646435, -- HORDE    | Dragonmaw Port, Twilight Highlands -- Only available after completion of H [84] Traitor's Bait [26830]
			[47644] = 1445551, -- HORDE    | Ruins of Southshore, Hillsbrad
			[47655] = 1411553, -- HORDE    | Southpoint Gate, Hillsbrad
			[47661] = 1463554, -- HORDE    | Eastpoint Tower, Hillsbrad
			[47665] = 1460596, -- HORDE    | Strahnbrad, Alterac Mountains
			[47875] = 1478673, -- NEUTRAL  | Hearthglen, Western Plaguelands
			[47927] = 1469327, -- NEUTRAL  | Iron Summit, Searing Gorge
			[48318] = 1462293, -- NEUTRAL  | Flamestar Post, Burning Steppes
			[48321] = 1493301, -- NEUTRAL  | Chiselgrip, Burning Steppes
			[50463] = 1373611, -- HORDE    | Forsaken Rear Guard, Silverpine Forest

			[40851] = 1277362, -- NEUTRAL  | Silver Tide Hollow, Vashj'ir -- UNDERWATER
			[40852] = 1305415, -- NEUTRAL  | Smuggler's Scar, Vashj'ir -- UNDERWATER
			[40871] = 1280338, -- HORDE    | Legion's Rest, Vashj'ir -- UNDERWATER
			[40873] = 1215348, -- HORDE    | Tenebrous Cavern, Vashj'ir -- UNDERWATER
			[43216] = 1297377, -- HORDE    | Sandy Beach, Vashj'ir -- UNDERWATER
			[43293] = 1277335, -- HORDE    | Stygian Bounty, Vashj'ir -- UNDERWATER -- Only available after completion of N [81] A Breath of Fresh Air [26006]
		},
		["Outland"] = {
			[16587] = 1655497, -- HORDE    | Thrallmar, Hellfire Peninsula
			[18791] = 1233496, -- HORDE    | Zabra'jin, Zangarmarsh
			[18807] = 1509269, -- HORDE    | Stonebreaker Hold, Terokkar Forest
			[18808] = 1288375, -- HORDE    | Garadar, Nagrand
			[18930] = 1786464, -- HORDE    | Hellfire Peninsula, The Dark Portal
			[18938] = 1577729, -- NEUTRAL  | Area 52, Netherstorm
			[18940] = 1438328, -- NEUTRAL  | Shattrath, Terokkar Forest
			[18942] = 1536430, -- HORDE    | Falcon Watch, Hellfire Peninsula
			[18953] = 1379678, -- HORDE    | Thunderlord Stronghold, Blade's Edge Mountains
			[19317] = 1661232, -- HORDE    | Shadowmoon Village, Shadowmoon Valley
			[19558] = 1678371, -- HORDE    | Spinebreaker Ridge, Hellfire Peninsula
			[19581] = 1809228, -- NEUTRAL  | Altar of Sha'tar, Shadowmoon Valley -- Aldor only!
			[19583] = 1629817, -- NEUTRAL  | The Stormspire, Netherstorm
			[20515] = 1719721, -- NEUTRAL  | Cosmowrench, Netherstorm
			[20762] = 1445486, -- HORDE    | Swamprat Post, Zangarmarsh
			[21766] = 1778146, -- NEUTRAL  | Sanctum of the Stars, Shadowmoon Valley -- Scryers only!
			[22216] = 1421721, -- NEUTRAL  | Evergrove, Blade's Edge Mountains
			[22455] = 1486644, -- HORDE    | Mok'Nathal Village, Blade's Edge Mountains
		},
		["Northrend"] = {
			[24032] = 1836413, -- HORDE    | Camp Winterhoof, Howling Fjord
			[24155] = 1846267, -- HORDE    | New Agamand, Howling Fjord
			[24795] = 1166473, -- NEUTRAL  | Amber Ledge, Borean Tundra
			[25288] = 1148430, -- HORDE    | Warsong Hold, Borean Tundra
			[26566] = 1453491, -- HORDE    | Agmar's Hammer, Dragonblight
			[26844] = 1744378, -- HORDE    | Apothecary Camp, Howling Fjord
			[26845] = 1595451, -- HORDE    | Venomspite, Dragonblight
			[26847] = 1287464, -- HORDE    | Taunka'le Village, Borean Tundra
			[26848] = 1182531, -- HORDE    | Bor'gorok Outpost, Borean Tundra
			[26850] = 1476561, -- HORDE    | Kor'kron Vanguard, Dragonblight
			[26851] = 1536478, -- NEUTRAL  | Wyrmrest Temple, Dragonblight
			[26852] = 1698452, -- HORDE    | Conquest Hold, Grizzly Hills
			[26853] = 1844492, -- HORDE    | Camp Oneqwah, Grizzly Hills
			[27046] = 1121473, -- NEUTRAL  | Transitus Shield, Coldarra
			[27344] = 1951365, -- HORDE    | Vengeance Landing, Howling Fjord
			[28037] = 1175603, -- NEUTRAL  | Nesingwary Base Camp, Sholazar Basin -- Only available after completion of N [76] Have a Part, Give a Part [12523]
			[28195] = 1290430, -- NEUTRAL  | Unu'pe, Borean Tundra
			[28196] = 1493422, -- NEUTRAL  | Moa'ki, Dragonblight
			[28197] = 1739292, -- NEUTRAL  | Kamagua, Howling Fjord
			[28574] = 1245597, -- NEUTRAL  | River's Heart, Sholazar Basin
			[28615] = 1636579, -- NEUTRAL  | Ebon Watch, Zul'Drak
			[28618] = 1695577, -- NEUTRAL  | Light's Breach, Zul'Drak
			[28623] = 1725598, -- NEUTRAL  | The Argent Stand, Zul'Drak
			[28624] = 1784615, -- NEUTRAL  | Zim'Torga, Zul'Drak
			[28674] = 1523617, -- NEUTRAL  | Dalaran
			[29721] = 1620641, -- NEUTRAL  | K3, The Storm Peaks
			[29757] = 1599749, -- HORDE    | Grom'arsh Crash-Site, The Storm Peaks
			[29762] = 1734745, -- HORDE    | Camp Tunka'lo, The Storm Peaks
			[29950] = 1574789, -- NEUTRAL  | Bouldercrag's Refuge, The Storm Peaks
			[29951] = 1637815, -- NEUTRAL  | Ulduar, The Storm Peaks
			[30269] = 1597603, -- HORDE    | Sunreaver's Command, Crystalsong Forest
			[30314] = 1377785, -- NEUTRAL  | The Shadow Vault, Icecrown -- Only available after completion of N [80] If He Cannot Be Turned [12897]
			[30433] = 1556640, -- NEUTRAL  | The Argent Vanguard, Icecrown
			[30569] = 1818687, -- NEUTRAL  | Gundrak, Zul'Drak
			[30870] = 1313566, -- HORDE    | Warsong Camp, Wintergrasp
			[31069] = 1522655, -- NEUTRAL  | Crusaders' Pinnacle, Icecrown -- Only available after completion of N [79] The Battle For Crusaders' Pinnacle [13141]
			[31078] = 1279722, -- NEUTRAL  | Death's Rise, Icecrown
			[32571] = 1720714, -- NEUTRAL  | Dun Niffelem, The Storm Peaks -- Only available after completion of N [80] A Spark of Hope [12956]
			[33849] = 1494789, -- NEUTRAL  | Argent Tournament Grounds, Icecrown
		},
		["Pandaria"] = {
			--[691] = TODO 
			[58843] = 1478336, -- NEUTRAL  | Stoneplow, Valley of the Four Winds
			[59046] = 1622299, -- HORDE    | Thunder Cleft, Krasarang Wilds
			[59047] = 1503231, -- HORDE    | Dawnchaser Retreat, Krasarang Wilds
			[59186] = 1791499, -- NEUTRAL  | Dawn's Blossom, Jade Forest
			[59727] = 1835438, -- NEUTRAL  | Jade Temple Grounds, Jade Forest
			[59732] = 1849507, -- NEUTRAL  | The Arboretum, Jade Forest
			[59733] = 1840587, -- NEUTRAL  | Sri-La Village, Jade Forest
			[59735] = 1813574, -- NEUTRAL  | Emperor's Omen, Jade Forest
			[59736] = 1770583, -- NEUTRAL  | Tian Monastery, Jade Forest
			[60230] = 1690418, -- NEUTRAL  | Pang's Stead, Valley of the Four Winds
			[60231] = 1589353, -- NEUTRAL  | Halfhill, Valley of the Four Winds
			[60232] = 1691341, -- NEUTRAL  | Zhu's Watch, Krasarang Wilds
			[60416] = 1455601, -- NEUTRAL  | Kota Basecamp, Kun-Lai Summit
			[60441] = 1595162, -- NEUTRAL  | Marista, Krasarang Wilds
			[60952] = 1678492, -- HORDE    | Grookin Hill, Jade Forest -- Only available after completion of H [85] Instant Messaging [questID 29936]
			[61118] = 1578667, -- NEUTRAL  | Temple of the White Tiger, Kun-Lai Summit
			[61122] = 1561505, -- HORDE    | Shrine of Two Moons, Vale of Eternal Blossoms
			[61473] = 1461531, -- NEUTRAL  | Shado-Pan Fallback, Kun-Lai Summit
			[61474] = 1611515, -- NEUTRAL  | Binan Village, Kun-Lai Summit
			[61504] = 1534635, -- NEUTRAL  | One Keg, Kun-Lai Summit
			[61511] = 1558739, -- NEUTRAL  | Zouchin Village, Kun-Lai Summit
			[61512] = 1411638, -- NEUTRAL  | Winter's Blossom, Kun-Lai Summit
			[61745] = 1558562, -- HORDE    | Eastwind Rest, Kun-Lai Summit -- Only available after completion of H [87] Challenge Accepted [questID 30515]
			[61759] = 1654439, -- NEUTRAL  | Tavern in the Mists, The Veiled Stair
			[62658] = 1645411, -- NEUTRAL  | Grassy Cline, Valley of the Four Winds
			[62898] = 1303501, -- NEUTRAL  | Rensai's Watchpost, Townlong Steppes
			[62901] = 1385571, -- NEUTRAL  | Longying Outpost, Townlong Steppes
			[62903] = 1401494, -- NEUTRAL  | Gao-Ran Battlefront, Townlong Steppes
			[62909] = 1283524, -- NEUTRAL  | Shado-Pan Garrison, Townlong Steppes
			[63497] = 1458424, -- NEUTRAL  | Serpent's Spine, Vale of Eternal Blossoms
			[63498] = 1373281, -- NEUTRAL  | Soggy's Gamble, Dread Wastes
			[63500] = 1346455, -- NEUTRAL  | The Sunset Brewgarden, Dread Wastes
			[63501] = 1371387, -- NEUTRAL  | Klaxxi'vess, Dread Wastes
			[64310] = 1768412, -- NEUTRAL  | Serpent's Overlook, Jade Forest
			[65189] = 1512198, -- NEUTRAL  | Cradle of Chi-Ji, Krasarang Wilds
			[65511] = 1312325, -- NEUTRAL  | The Briny Muck, Dread Wastes
		},
	},
	["Alliance"] = {
		["Kalimdor"] = {
			 [3838] = 1410832, -- ALLIANCE | Rut'theran Village, Teldrassil
			 [3841] = 1464794, -- ALLIANCE | Lor'danel, Darkshore
			 [4267] = 1463604, -- ALLIANCE | Astranaar, Ashenvale
			 [4321] = 1636331, -- ALLIANCE | Theramore, Dustwallow Marsh
			 [4407] = 1388576, -- ALLIANCE | Thal'darah Overlook, Stonetalon Mountains
			 [6706] = 1396493, -- ALLIANCE | Nijel's Point, Desolace
			 [7823] = 1606192, -- ALLIANCE | Gadgetzan, Tanaris
			[10583] = 1514178, -- NEUTRAL  | Marshal's Stand, Un'Goro Crater
			[10897] = 1553794, -- ALLIANCE | Moonglade
			[11138] = 1646767, -- ALLIANCE | Everlook, Winterspring
			[12578] = 1528743, -- ALLIANCE | Talonbranch Glade, Felwood
			[15177] = 1419210, -- ALLIANCE | Cenarion Hold, Silithus
			[16227] = 1606451, -- NEUTRAL  | Ratchet, Northern Barrens
			[17554] = 1219825, -- ALLIANCE | Blood Watch, Bloodmyst Isle
			[17555] = 1206745, -- ALLIANCE | The Exodar
			[22931] = 1505651, -- NEUTRAL  | Emerald Sanctuary, Felwood
			[22935] = 1582611, -- ALLIANCE | Forest Song, Ashenvale
			[33253] = 1445692, -- ALLIANCE | Grove of the Ancients, Darkshore
			[34374] = 1424647, -- ALLIANCE | Blackfathom Camp, Ashenvale
			[34378] = 1464566, -- ALLIANCE | Stardust Spire, Ashenvale
			[35138] = 1368528, -- ALLIANCE | Farwatcher's Glen, Stonetalon Mountains
			[35136] = 1462497, -- ALLIANCE | Northwatch Expedition Base Camp, Stonetalon Mountains
			[35137] = 1433540, -- ALLIANCE | Windshear Hold, Stonetalon Mountains
			[35478] = 1383445, -- NEUTRAL  | Karnum's Glade, Desolace
			[35481] = 1345418, -- ALLIANCE | Thargad's Camp, Desolace
			[35556] = 1407466, -- NEUTRAL  | Thunk's Abode, Desolace
			[35562] = 1349473, -- NEUTRAL  | Ethel Rethor, Desolace
			[39175] = 1496202, -- NEUTRAL  | Mossy Pile, Un'Goro Crater
			[39210] = 1514474, -- ALLIANCE | Honor's Stand, Southern Barrens
			[39211] = 1545358, -- ALLIANCE | Fort Triumph, Southern Barrens
			[39212] = 1597400, -- ALLIANCE | Northwatch Hold, Southern Barrens
			[40358] = 1583300, -- NEUTRAL  | Mudsprocket, Dustwallow Marsh
			[40367] = 1448282, -- ALLIANCE | Shadebough, Feralas
			[40552] = 1343897, -- ALLIANCE | Darnassus, Teldrassil
			[40553] = 1411893, -- ALLIANCE | Dolanaar, Teldrassil
			[40768] = 1611238, -- ALLIANCE | Fizzle & Pozzik's Speedbarge, Thousand Needles
			[40827] = 1572098, -- ALLIANCE | Gunstan's Dig, Tanaris
			[40966] = 1371359, -- ALLIANCE | Dreamer's Rest, Feralas
			[41214] = 1619131, -- NEUTRAL  | Bootlegger Outpost, Tanaris
			[41240] = 1408544, -- ALLIANCE | Mirkfallon Post, Stonetalon Mountains
			[41383] = 1361304, -- ALLIANCE | Feathermoon, Feralas
			[41580] = 1390288, -- ALLIANCE | Tower of Estulan, Feralas
			[41860] = 1523700, -- NEUTRAL  | Grove of Aessina, Hyjal
			[41861] = 1597717, -- NEUTRAL  | Nordrassil, Hyjal
			[43073] = 1485737, -- NEUTRAL  | Whisperwind Grove, Felwood
			[43079] = 1487682, -- NEUTRAL  | Wildheart Point, Felwood
			[43481] = 1561693, -- NEUTRAL  | Shrine of Aviana, Hyjal
			[43549] = 1614654, -- NEUTRAL  | Gates of Sothann, Hyjal -- Only available after completion of N [81] Slash and Burn [25608]
			[43991] = 1242734, -- ALLIANCE | Azure Watch, Azuremyst Isle
			[48273] = 1407048, -- NEUTRAL  | Schnottz's Landing, Uldum
			[48274] = 1418144, -- NEUTRAL  | Oasis of Vir'sar, Uldum
			[48275] = 1494101, -- NEUTRAL  | Ramkahen, Uldum
			[54392] = 1537668, -- NEUTRAL  | Sanctuary of Malorne, Hyjal
			[54393] = 1537668, -- NEUTRAL  | Sanctuary of Malorne, Hyjal
		},
		["EasternKingdoms"] = {
			  [352] = 1409267, -- ALLIANCE | Stormwind, Elwynn
			  [523] = 1390208, -- ALLIANCE | Sentinel Hill, Westfall
			  [931] = 1504247, -- ALLIANCE | Lakeshire, Redridge
			 [1571] = 1453442, -- ALLIANCE | Menethil Harbor, Wetlands
			 [1572] = 1528386, -- ALLIANCE | Thelsamar, Loch Modan
			 [1573] = 1466407, -- ALLIANCE | Ironforge, Dun Morogh
			 [2299] = 1521284, -- ALLIANCE | Morgan's Vigil, Burning Steppes
			 [2409] = 1470209, -- ALLIANCE | Darkshire, Duskwood
			 [2835] = 1513531, -- ALLIANCE | Refuge Pointe, Arathi
			 [2859] = 1410071, -- ALLIANCE | Booty Bay, Stranglethorn
			 [2941] = 1467346, -- ALLIANCE | Thorium Point, Searing Gorge
			 [8018] = 1496584, -- ALLIANCE | Aerie Peak, The Hinterlands
			 [8609] = 1545188, -- ALLIANCE | Nethergarde Keep, Blasted Lands
			[12596] = 1476606, -- ALLIANCE | Chillwind Camp, Western Plaguelands
			[12617] = 1611653, -- ALLIANCE | Light's Hope Chapel, Eastern Plaguelands
			[24851] = 1612726, -- NEUTRAL  | Zul'Aman, Ghostlands
			[26560] = 1583942, -- NEUTRAL  | Shattered Sun Staging Area
			[28621] = 1577683, -- NEUTRAL  | Northpass Tower, Eastern Plaguelands
			[29480] = 1623656, -- NEUTRAL  | Acherus: The Ebon Hold -- Death Knight only
			[37888] = 1520641, -- NEUTRAL  | Thondroril River, Eastern Plaguelands
			[41321] = 1521431, -- ALLIANCE | Slabchisel's Survey, Wetlands
			[41322] = 1520459, -- ALLIANCE | Greenwarden's Grove, Wetlands
			[41323] = 1495462, -- ALLIANCE | Whelgar's Retreat, Wetlands
			[41325] = 1512482, -- ALLIANCE | Dun Modr, Wetlands
			[41332] = 1574377, -- ALLIANCE | Farstrider Lodge, Loch Modan
			[42406] = 1382232, -- ALLIANCE | Furlbrow's Pumpkin Farm, Westfall
			[42426] = 1372196, -- ALLIANCE | Moonbrook, Westfall
			[42983] = 1423246, -- ALLIANCE | Goldshire, Elwynn
			[43000] = 1471245, -- ALLIANCE | Eastvale Logging Camp, Elwynn
			[43042] = 1440129, -- ALLIANCE | Fort Livingston, Stranglethorn
			[43043] = 1429102, -- ALLIANCE | Explorers' League Digsite, Stranglethorn
			[43045] = 1434180, -- ALLIANCE | Rebel Camp, Stranglethorn Vale
			[43072] = 1547239, -- ALLIANCE | Shalewind Canyon, Redridge
			[43086] = 1561236, -- NEUTRAL  | Bogpaddle, Swamp of Sorrows
			[43087] = 1559221, -- ALLIANCE | Marshtide Watch, Swamp of Sorrows
			[43088] = 1525223, -- ALLIANCE | The Harborage, Swamp of Sorrows
			[43107] = 1527131, -- ALLIANCE | Surwich, Blasted Lands
			[43290] = 1290390, -- ALLIANCE | Sandy Beach, Vashj'ir
			[43295] = 1290324, -- ALLIANCE | Voldrin's Hold, Vashj'ir -- Only available after completion of N [81] A Breath of Fresh Air [26005]
			[43371] = 1525246, -- ALLIANCE | Camp Everstill, Redridge
			[43570] = 1569585, -- ALLIANCE | Stormfeather Outpost, The Hinterlands
			[43697] = 1417201, -- ALLIANCE | Raven Hill, Duskwood
			[43701] = 1443377, -- ALLIANCE | Kharanos, Dun Morogh
			[43702] = 1481376, -- ALLIANCE | Gol'Bolar Quarry, Dun Morogh
			[44230] = 1592662, -- NEUTRAL  | Eastwall Tower, Eastern Plaguelands
			[44231] = 1579653, -- NEUTRAL  | Light's Shield Tower, Eastern Plaguelands
			[44232] = 1554639, -- NEUTRAL  | Crown Guard Tower, Eastern Plaguelands
			[44233] = 1531677, -- NEUTRAL  | Plaguewood Tower, Eastern Plaguelands
			[44407] = 1561346, -- NEUTRAL  | Fuselight, Badlands
			[44409] = 1544345, -- ALLIANCE | Dustwind Dig, Badlands
			[44410] = 1515330, -- ALLIANCE | Dragon's Mouth, Badlands
			[46006] = 1471622, -- ALLIANCE | Andorhal, Western Plaguelands -- becomes unavailable after completion of A [40] Alas, Andorhal [27206]
			[46011] = 1487639, -- NEUTRAL  | The Menders' Stead, Western Plaguelands
			[47118] = 1591429, -- ALLIANCE | Victor's Point, Twilight Highlands
			[47119] = 1660405, -- ALLIANCE | Highbank, Twilight Highlands -- Only available after completion of A [84] Aiming High [28598]
			[47121] = 1563469, -- NEUTRAL  | Vermillion Redoubt, Twilight Highlands -- Only available after completion of N [85] In Defense of the Redoubt [27564]
			[47147] = 1621429, -- ALLIANCE | Firebeard's Patrol, Twilight Highlands
			[47154] = 1599465, -- ALLIANCE | Thundermar, Twilight Highlands
			[47155] = 1614481, -- ALLIANCE | Kirthaven, Twilight Highlands
			[47875] = 1478673, -- NEUTRAL  | Hearthglen, Western Plaguelands
			[47927] = 1469327, -- NEUTRAL  | Iron Summit, Searing Gorge
			[48318] = 1462293, -- NEUTRAL  | Flamestar Post, Burning Steppes
			[48321] = 1493301, -- NEUTRAL  | Chiselgrip, Burning Steppes

			[40851] = 1277362, -- NEUTRAL  | Silver Tide Hollow, Vashj'ir -- UNDERWATER
			[40852] = 1305415, -- NEUTRAL  | Smuggler's Scar, Vashj'ir -- UNDERWATER
			[40866] = 1220334, -- ALLIANCE | Darkbreak Cove, Vashj'ir -- UNDERWATER
			[40867] = 1276344, -- ALLIANCE | Tranquil Wash, Vashj'ir -- UNDERWATER
			[43287] = 1291391, -- ALLIANCE | Sandy Beach, Vashj'ir -- UNDERWATER
			[43289] = 1290324, -- ALLIANCE | Voldrin's Hold, Vashj'ir -- UNDERWATER -- Only available after completion of N [81] A Breath of Fresh Air [26005]
		},
		["Outland"] = {
			[16822] = 1648423, -- ALLIANCE | Honor Hold, Hellfire Peninsula
			[18785] = 1524494, -- ALLIANCE | Temple of Telhamat, Hellfire Peninsula
			[18788] = 1375496, -- ALLIANCE | Telredor, Zangarmarsh
			[18789] = 1274256, -- ALLIANCE | Telaar, Nagrand
			[18809] = 1554235, -- ALLIANCE | Allerian Stronghold, Terokkar Forest
			[18931] = 1787451, -- ALLIANCE | Hellfire Peninsula, The Dark Portal
			[18937] = 1316656, -- ALLIANCE | Sylvanaar, Blade's Edge Mountains
			[18938] = 1577729, -- NEUTRAL  | Area 52, Netherstorm
			[18939] = 1694154, -- ALLIANCE | Wildhammer Stronghold, Shadowmoon Valley
			[18940] = 1438328, -- NEUTRAL  | Shattrath, Terokkar Forest
			[19581] = 1809228, -- NEUTRAL  | Altar of Sha'tar, Shadowmoon Valley -- Aldor only!
			[19583] = 1629817, -- NEUTRAL  | The Stormspire, Netherstorm
			[20234] = 1749501, -- ALLIANCE | Shatter Point, Hellfire Peninsula
			[20515] = 1719721, -- NEUTRAL  | Cosmowrench, Netherstorm
			[21107] = 1419630, -- ALLIANCE | Toshley's Station, Blade's Edge Mountains
			[21766] = 1778146, -- NEUTRAL  | Sanctum of the Stars, Shadowmoon Valley -- Scryers only!
			[22216] = 1421721, -- NEUTRAL  | Evergrove, Blade's Edge Mountains
			[22485] = 1267557, -- ALLIANCE | Orebor Harborage, Zangarmarsh
		},
		["Northrend"] = {
			[23736] = 1876278, -- ALLIANCE | Valgarde Port, Howling Fjord
			[23859] = 1764328, -- ALLIANCE | Westguard Keep, Howling Fjord
			[24061] = 1877401, -- ALLIANCE | Fort Wildervar, Howling Fjord
			[24795] = 1166473, -- NEUTRAL  | Amber Ledge, Borean Tundra
			[26602] = 1208508, -- ALLIANCE | Fizzcrank Airstrip, Borean Tundra
			[26851] = 1536478, -- NEUTRAL  | Wyrmrest Temple, Dragonblight
			[26876] = 1827538, -- ALLIANCE | Westfall Brigade, Grizzly Hills
			[26877] = 1461540, -- ALLIANCE | Fordragon Hold, Dragonblight
			[26878] = 1597481, -- ALLIANCE | Wintergarde Keep, Dragonblight
			[26879] = 1217388, -- ALLIANCE | Valiance Keep, Borean Tundra
			[26880] = 1730464, -- ALLIANCE | Amberpine Lodge, Grizzly Hills
			[26881] = 1423468, -- ALLIANCE | Stars' Rest, Dragonblight
			[27046] = 1121473, -- NEUTRAL  | Transitus Shield, Coldarra
			[28037] = 1175603, -- NEUTRAL  | Nesingwary Base Camp, Sholazar Basin -- Only available after completion of N [76] Have a Part, Give a Part [12523]
			[28195] = 1290430, -- NEUTRAL  | Unu'pe, Borean Tundra
			[28196] = 1493422, -- NEUTRAL  | Moa'ki, Dragonblight
			[28197] = 1739292, -- NEUTRAL  | Kamagua, Howling Fjord
			[28574] = 1245597, -- NEUTRAL  | River's Heart, Sholazar Basin
			[28615] = 1636579, -- NEUTRAL  | Ebon Watch, Zul'Drak
			[28618] = 1695577, -- NEUTRAL  | Light's Breach, Zul'Drak
			[28623] = 1725598, -- NEUTRAL  | The Argent Stand, Zul'Drak
			[28624] = 1784615, -- NEUTRAL  | Zim'Torga, Zul'Drak
			[28674] = 1523617, -- NEUTRAL  | Dalaran
			[29721] = 1620641, -- NEUTRAL  | K3, The Storm Peaks
			[29750] = 1569672, -- ALLIANCE | Frosthold, The Storm Peaks
			[29950] = 1574789, -- NEUTRAL  | Bouldercrag's Refuge, The Storm Peaks
			[29951] = 1637815, -- NEUTRAL  | Ulduar, The Storm Peaks
			[30271] = 1585567, -- ALLIANCE | Windrunner's Overlook, Crystalsong Forest
			[30314] = 1377785, -- NEUTRAL  | The Shadow Vault, Icecrown -- Only available after completion of N [80] If He Cannot Be Turned [12897]
			[30433] = 1556640, -- NEUTRAL  | The Argent Vanguard, Icecrown
			[30569] = 1818687, -- NEUTRAL  | Gundrak, Zul'Drak
			[30869] = 1410571, -- ALLIANCE | Valiance Landing Camp, Wintergrasp
			[31069] = 1522655, -- NEUTRAL  | Crusaders' Pinnacle, Icecrown -- Only available after completion of N [79] The Battle For Crusaders' Pinnacle [13141]
			[31078] = 1279722, -- NEUTRAL  | Death's Rise, Icecrown
			[32571] = 1720714, -- NEUTRAL  | Dun Niffelem, The Storm Peaks -- Only available after completion of N [80] A Spark of Hope [12956]
			[33849] = 1494789, -- NEUTRAL  | Argent Tournament Grounds, Icecrown
		},
		["Pandaria"] = {
			  [487] = 1785347, -- ALLIANCE | Paw'Don Village, Jade Forest
			[56737] = 1855357, -- ALLIANCE | Pearlfin Village, Jade Forest
			[58843] = 1478336, -- NEUTRAL  | Stoneplow, Valley of the Four Winds
			[59048] = 1488275, -- ALLIANCE | Sentinel Basecamp, Krasarang Wilds
			[59049] = 1656278, -- ALLIANCE | The Incursion, Krasarang Wilds -- Only available after completion of A [86] The Arcanic Oubliette [30274]
			[59186] = 1791499, -- NEUTRAL  | Dawn's Blossom, Jade Forest
			[59727] = 1835438, -- NEUTRAL  | Jade Temple Grounds, Jade Forest
			[59732] = 1849507, -- NEUTRAL  | The Arboretum, Jade Forest
			[59733] = 1840587, -- NEUTRAL  | Sri-La Village, Jade Forest
			[59735] = 1813574, -- NEUTRAL  | Emperor's Omen, Jade Forest
			[59736] = 1770583, -- NEUTRAL  | Tian Monastery, Jade Forest
			[60230] = 1690418, -- NEUTRAL  | Pang's Stead, Valley of the Four Winds
			[60231] = 1589353, -- NEUTRAL  | Halfhill, Valley of the Four Winds
			[60232] = 1691341, -- NEUTRAL  | Zhu's Watch, Krasarang Wilds
			[60416] = 1455601, -- NEUTRAL  | Kota Basecamp, Kun-Lai Summit
			[60441] = 1595162, -- NEUTRAL  | Marista, Krasarang Wilds
			[61118] = 1578667, -- NEUTRAL  | Temple of the White Tiger, Kun-Lai Summit
			[61121] = 1608448, -- ALLIANCE | Shrine of Seven Stars, Vale of Eternal Blossoms
			[61473] = 1461531, -- NEUTRAL  | Shado-Pan Fallback, Kun-Lai Summit
			[61474] = 1611515, -- NEUTRAL  | Binan Village, Kun-Lai Summit
			[61504] = 1534635, -- NEUTRAL  | One Keg, Kun-Lai Summit
			[61511] = 1558739, -- NEUTRAL  | Zouchin Village, Kun-Lai Summit
			[61512] = 1411638, -- NEUTRAL  | Winter's Blossom, Kun-Lai Summit
			[61744] = 1513549, -- ALLIANCE | Westwind Rest, Kun-Lai Summit -- Only available after completion of A [87] Challenge Accepted [30514]
			[61759] = 1654439, -- NEUTRAL  | Tavern in the Mists, The Veiled Stair
			[62658] = 1645411, -- NEUTRAL  | Grassy Cline, Valley of the Four Winds
			[62898] = 1303501, -- NEUTRAL  | Rensai's Watchpost, Townlong Steppes
			[62901] = 1385571, -- NEUTRAL  | Longying Outpost, Townlong Steppes
			[62903] = 1401494, -- NEUTRAL  | Gao-Ran Battlefront, Townlong Steppes
			[62909] = 1283524, -- NEUTRAL  | Shado-Pan Garrison, Townlong Steppes
			[63497] = 1458424, -- NEUTRAL  | Serpent's Spine, Vale of Eternal Blossoms
			[63498] = 1373281, -- NEUTRAL  | Soggy's Gamble, Dread Wastes
			[63500] = 1346455, -- NEUTRAL  | The Sunset Brewgarden, Dread Wastes
			[63501] = 1371387, -- NEUTRAL  | Klaxxi'vess, Dread Wastes
			[64310] = 1768412, -- NEUTRAL  | Serpent's Overlook, Jade Forest
			[65189] = 1512198, -- NEUTRAL  | Cradle of Chi-Ji, Krasarang Wilds
			[65511] = 1312325, -- NEUTRAL  | The Briny Muck, Dread Wastes
		},
	},
}